.. galsampler documentation master file, created by
   sphinx-quickstart on Mon Sep  5 09:47:02 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to galsampler's documentation
======================================

`galsampler <https://github.com/LSSTDESC/galsampler/>`__
is a Python package for making mock catalogs of galaxies using
`the GalSampler technique <https://arxiv.org/abs/1909.07340/>`__,
in which an existing catalog of mock galaxies is transferred
to the dark matter halos in a larger-volume simulation.
GalSampler was originally developed to generate the
`CosmoDC2 <https://arxiv.org/abs/1907.06530/>`__ mock galaxy catalog
used by the Dark Energy Science Collaboration (`DESC <https://lsstdesc.org/>`__),
and is now being used to make mocks for the Emulator Mock Challenge
in the Dark Energy Spectroscopic Instrument (`DESI <https://www.desi.lbl.gov/>`__).


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Installation instructions <installation.rst>
   Overview <intro.rst>
   API reference <reference.rst>
